@@ -1,12 +1,10 @@
 package SVN::Notify::HTML::ColorDiff;
 
-# $Id: ColorDiff.pm 4750 2010-01-16 04:32:23Z david $
-
 use strict;
 use HTML::Entities;
 use SVN::Notify::HTML ();
 
-$SVN::Notify::HTML::ColorDiff::VERSION = '2.80';
+$SVN::Notify::HTML::ColorDiff::VERSION = '2.82';
 @SVN::Notify::HTML::ColorDiff::ISA = qw(SVN::Notify::HTML);
 
 =head1 Name
@@ -273,11 +271,11 @@ body. Maybe use absolute positioning CSS?
 
 =head1 Author
 
-David E. Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2004-2009 Kineticode, Inc. Some Rights Reserved.
+Copyright (c) 2004-2011 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
